/**
 * chroma.js - JavaScript library for color conversions
 *
 * Copyright (c) 2011-2024, Gregor Aisch
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name Gregor Aisch may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL GREGOR AISCH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * -------------------------------------------------------
 *
 * chroma.js includes colors from colorbrewer2.org, which are released under
 * the following license:
 *
 * Copyright (c) 2002 Cynthia Brewer, Mark Harrower,
 * and The Pennsylvania State University.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * ------------------------------------------------------
 *
 * Named colors are taken from X11 Color Names.
 * http://www.w3.org/TR/css3-color/#svg-color
 *
 * @preserve
 */

!function(t,r){"object"==typeof exports&&"undefined"!=typeof module?module.exports=r():"function"==typeof define&&define.amd?define(r):(t="undefined"!=typeof globalThis?globalThis:t||self).chroma=r()}(this,(function(){"use strict";function t(t,r,n){return void 0===n&&(n=1),l(c(r,t),n)}for(var r={},n=0,e=["Boolean","Number","String","Function","Array","Date","RegExp","Undefined","Null"];n<e.length;n+=1){var a=e[n];r["[object "+a+"]"]=a.toLowerCase()}function o(t){return r[Object.prototype.toString.call(t)]||"object"}function i(t,r){return void 0===r&&(r=null),t.length>=3?Array.prototype.slice.call(t):"object"==o(t[0])&&r?r.split("").filter((function(r){return void 0!==t[0][r]})).map((function(r){return t[0][r]})):t[0].slice(0)}function s(t){if(t.length<2)return null;var r=t.length-1;return"string"==o(t[r])?t[r].toLowerCase():null}var u=Math.PI,l=Math.min,c=Math.max,h=function(t){return Math.round(100*t)/100},f=function(t){return Math.round(100*t)/100},d=u/180,g=180/u,m={format:{},autodetect:[]},p=function(){for(var r=[],n=arguments.length;n--;)r[n]=arguments[n];var e=this;if("object"===o(r[0])&&r[0].constructor&&r[0].constructor===this.constructor)return r[0];var a=s(r),i=!1;if(!a){i=!0,m.sorted||(m.autodetect=m.autodetect.sort((function(t,r){return r.p-t.p})),m.sorted=!0);for(var u=0,l=m.autodetect;u<l.length;u+=1){var c=l[u];if(a=c.test.apply(c,r))break}}if(!m.format[a])throw new Error("unknown format: "+r);var h=m.format[a].apply(null,i?r:r.slice(0,-1));e._rgb=function(r){r._clipped=!1,r._unclipped=r.slice(0);for(var n=0;n<=3;n++)n<3?((r[n]<0||r[n]>255)&&(r._clipped=!0),r[n]=t(r[n],0,255)):3===n&&(r[n]=t(r[n],0,1));return r}(h),3===e._rgb.length&&e._rgb.push(1)};p.prototype.toString=function(){return"function"==o(this.hex)?this.hex():"["+this._rgb.join(",")+"]"};var v=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t)))};v.version="3.0.0";var b=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n,e,a=(t=i(t,"rgba"))[0],o=t[1],s=t[2],u=l(a/=255,o/=255,s/=255),h=c(a,o,s),f=(h+u)/2;return h===u?(n=0,e=Number.NaN):n=f<.5?(h-u)/(h+u):(h-u)/(2-h-u),a==h?e=(o-s)/(h-u):o==h?e=2+(s-a)/(h-u):s==h&&(e=4+(a-o)/(h-u)),(e*=60)<0&&(e+=360),t.length>3&&void 0!==t[3]?[e,n,f,t[3]]:[e,n,f]},y={Kn:18,labWhitePoint:"d65",Xn:.95047,Yn:1,Zn:1.08883,t0:.137931034,t1:.206896552,t2:.12841855,t3:.008856452,kE:216/24389,kKE:8,kK:24389/27,RefWhiteRGB:{X:.95047,Y:1,Z:1.08883},MtxRGB2XYZ:{m00:.4124564390896922,m01:.21267285140562253,m02:.0193338955823293,m10:.357576077643909,m11:.715152155287818,m12:.11919202588130297,m20:.18043748326639894,m21:.07217499330655958,m22:.9503040785363679},MtxXYZ2RGB:{m00:3.2404541621141045,m01:-.9692660305051868,m02:.055643430959114726,m10:-1.5371385127977166,m11:1.8760108454466942,m12:-.2040259135167538,m20:-.498531409556016,m21:.041556017530349834,m22:1.0572251882231791},As:.9414285350000001,Bs:1.040417467,Cs:1.089532651,MtxAdaptMa:{m00:.8951,m01:-.7502,m02:.0389,m10:.2664,m11:1.7135,m12:-.0685,m20:-.1614,m21:.0367,m22:1.0296},MtxAdaptMaI:{m00:.9869929054667123,m01:.43230526972339456,m02:-.008528664575177328,m10:-.14705425642099013,m11:.5183602715367776,m12:.04004282165408487,m20:.15996265166373125,m21:.0492912282128556,m22:.9684866957875502}},w=new Map([["a",[1.0985,.35585]],["b",[1.0985,.35585]],["c",[.98074,1.18232]],["d50",[.96422,.82521]],["d55",[.95682,.92149]],["d65",[.95047,1.08883]],["e",[1,1,1]],["f2",[.99186,.67393]],["f7",[.95041,1.08747]],["f11",[1.00962,.6435]],["icc",[.96422,.82521]]]);function M(t){var r=w.get(String(t).toLowerCase());if(!r)throw new Error("unknown Lab illuminant "+t);y.labWhitePoint=t,y.Xn=r[0],y.Zn=r[1]}function k(){return y.labWhitePoint}var x=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"rgb"),e=n[0],a=n[1],o=n[2],s=n.slice(3),u=A(e,a,o),l=function(t,r,n){var e=y.Xn,a=y.Yn,o=y.Zn,i=y.kE,s=y.kK,u=t/e,l=r/a,c=n/o,h=u>i?Math.pow(u,1/3):(s*u+16)/116,f=l>i?Math.pow(l,1/3):(s*l+16)/116,d=c>i?Math.pow(c,1/3):(s*c+16)/116;return[116*f-16,500*(h-f),200*(f-d)]}(u[0],u[1],u[2]);return[l[0],l[1],l[2]].concat(s.length>0&&s[0]<1?[s[0]]:[])};function _(t){var r=Math.sign(t);return((t=Math.abs(t))<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4))*r}var A=function(t,r,n){t=_(t/255),r=_(r/255),n=_(n/255);var e=y.MtxRGB2XYZ,a=y.MtxAdaptMa,o=y.MtxAdaptMaI,i=y.Xn,s=y.Yn,u=y.Zn,l=y.As,c=y.Bs,h=y.Cs,f=t*e.m00+r*e.m10+n*e.m20,d=t*e.m01+r*e.m11+n*e.m21,g=t*e.m02+r*e.m12+n*e.m22,m=i*a.m00+s*a.m10+u*a.m20,p=i*a.m01+s*a.m11+u*a.m21,v=i*a.m02+s*a.m12+u*a.m22,b=f*a.m00+d*a.m10+g*a.m20,w=f*a.m01+d*a.m11+g*a.m21,M=f*a.m02+d*a.m12+g*a.m22;return w*=p/c,M*=v/h,[f=(b*=m/l)*o.m00+w*o.m10+M*o.m20,d=b*o.m01+w*o.m11+M*o.m21,g=b*o.m02+w*o.m12+M*o.m22]},j=Math.sqrt,$=Math.atan2,F=Math.round,X=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"lab"),e=n[0],a=n[1],o=n[2],s=j(a*a+o*o),u=($(o,a)*g+360)%360;return 0===F(1e4*s)&&(u=Number.NaN),[e,s,u]};function Z(t,r){var n=t.length;Array.isArray(t[0])||(t=[t]),Array.isArray(r[0])||(r=r.map((function(t){return[t]})));var e=r[0].length,a=r[0].map((function(t,n){return r.map((function(t){return t[n]}))})),o=t.map((function(t){return a.map((function(r){return Array.isArray(t)?t.reduce((function(t,n,e){return t+n*(r[e]||0)}),0):r.reduce((function(r,n){return r+n*t}),0)}))}));return 1===n&&(o=o[0]),1===e?o.map((function(t){return t[0]})):o}var E=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n,e,a=i(t,"rgb"),o=a[0],s=a[1],u=a[2],l=a.slice(3),c=A(o,s,u);return(n=[[.210454268309314,.7936177747023054,-.0040720430116193],[1.9779985324311684,-2.42859224204858,.450593709617411],[.0259040424655478,.7827717124575296,-.8086757549230774]],e=Z([[.819022437996703,.3619062600528904,-.1288737815209879],[.0329836539323885,.9292868615863434,.0361446663506424],[.0481771893596242,.2642395317527308,.6335478284694309]],c),Z(n,e.map((function(t){return Math.cbrt(t)})))).concat(l.length>0&&l[0]<1?[l[0]]:[])};var Y=Math.round,N=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"rgba"),e=s(t)||"rgb";if("hsl"===e.substr(0,3))return function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"hsla"),e=s(t)||"lsa";return n[0]=h(n[0]||0)+"deg",n[1]=h(100*n[1])+"%",n[2]=h(100*n[2])+"%","hsla"===e||n.length>3&&n[3]<1?(n[3]="/ "+(n.length>3?n[3]:1),e="hsla"):n.length=3,e.substr(0,3)+"("+n.join(" ")+")"}(b(n),e);if("lab"===e.substr(0,3)){var a=k();M("d50");var o=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"lab"),e=s(t)||"lab";return n[0]=h(n[0])+"%",n[1]=h(n[1]),n[2]=h(n[2]),"laba"===e||n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"lab("+n.join(" ")+")"}(x(n),e);return M(a),o}if("lch"===e.substr(0,3)){var u=k();M("d50");var l=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"lch"),e=s(t)||"lab";return n[0]=h(n[0])+"%",n[1]=h(n[1]),n[2]=h(n[2])+"deg","lcha"===e||n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"lch("+n.join(" ")+")"}(function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"rgb"),e=n[0],a=n[1],o=n[2],s=n.slice(3),u=x(e,a,o),l=u[0],c=u[1],h=u[2],f=X(l,c,h);return[f[0],f[1],f[2]].concat(s.length>0&&s[0]<1?[s[0]]:[])}(n),e);return M(u),l}return"oklab"===e.substr(0,5)?function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"lab");return n[0]=h(100*n[0])+"%",n[1]=f(n[1]),n[2]=f(n[2]),n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"oklab("+n.join(" ")+")"}(E(n)):"oklch"===e.substr(0,5)?function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"lab");return n[0]=h(100*n[0])+"%",n[1]=f(n[1]),n[2]=h(n[2])+"deg",n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"oklch("+n.join(" ")+")"}(function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"rgb"),e=n[0],a=n[1],o=n[2],s=n.slice(3),u=E(e,a,o),l=u[0],c=u[1],h=u[2],f=X(l,c,h);return[f[0],f[1],f[2]].concat(s.length>0&&s[0]<1?[s[0]]:[])}(n)):(n[0]=Y(n[0]),n[1]=Y(n[1]),n[2]=Y(n[2]),("rgba"===e||n.length>3&&n[3]<1)&&(n[3]="/ "+(n.length>3?n[3]:1),e="rgba"),e.substr(0,3)+"("+n.slice(0,"rgb"===e?3:4).join(" ")+")")},B=function(){for(var t,r=[],n=arguments.length;n--;)r[n]=arguments[n];var e,a,o,s=(r=i(r,"hsl"))[0],u=r[1],l=r[2];if(0===u)e=a=o=255*l;else{var c=[0,0,0],h=[0,0,0],f=l<.5?l*(1+u):l+u-l*u,d=2*l-f,g=s/360;c[0]=g+1/3,c[1]=g,c[2]=g-1/3;for(var m=0;m<3;m++)c[m]<0&&(c[m]+=1),c[m]>1&&(c[m]-=1),6*c[m]<1?h[m]=d+6*(f-d)*c[m]:2*c[m]<1?h[m]=f:3*c[m]<2?h[m]=d+(f-d)*(2/3-c[m])*6:h[m]=d;e=(t=[255*h[0],255*h[1],255*h[2]])[0],a=t[1],o=t[2]}return r.length>3?[e,a,o,r[3]]:[e,a,o,1]},C=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=(t=i(t,"lab"))[0],e=t[1],a=t[2],o=O(n,e,a),s=o[0],u=o[1],l=o[2],c=L(s,u,l);return[c[0],c[1],c[2],t.length>3?t[3]:1]},O=function(t,r,n){var e=y.kE,a=y.kK,o=y.kKE,i=y.Xn,s=y.Yn,u=y.Zn,l=(t+16)/116,c=.002*r+l,h=l-.005*n,f=c*c*c,d=h*h*h;return[(f>e?f:(116*c-16)/a)*i,(t>o?Math.pow((t+16)/116,3):t/a)*s,(d>e?d:(116*h-16)/a)*u]},R=function(t){var r=Math.sign(t);return((t=Math.abs(t))<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)*r},L=function(t,r,n){var e=y.MtxAdaptMa,a=y.MtxAdaptMaI,o=y.MtxXYZ2RGB,i=y.RefWhiteRGB,s=y.Xn,u=y.Yn,l=y.Zn,c=s*e.m00+u*e.m10+l*e.m20,h=s*e.m01+u*e.m11+l*e.m21,f=s*e.m02+u*e.m12+l*e.m22,d=i.X*e.m00+i.Y*e.m10+i.Z*e.m20,g=i.X*e.m01+i.Y*e.m11+i.Z*e.m21,m=i.X*e.m02+i.Y*e.m12+i.Z*e.m22,p=(t*e.m00+r*e.m10+n*e.m20)*(d/c),v=(t*e.m01+r*e.m11+n*e.m21)*(g/h),b=(t*e.m02+r*e.m12+n*e.m22)*(m/f),w=p*a.m00+v*a.m10+b*a.m20,M=p*a.m01+v*a.m11+b*a.m21,k=p*a.m02+v*a.m12+b*a.m22;return[255*R(w*o.m00+M*o.m10+k*o.m20),255*R(w*o.m01+M*o.m11+k*o.m21),255*R(w*o.m02+M*o.m12+k*o.m22)]},W=Math.sin,K=Math.cos,G=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"lch"),e=n[0],a=n[1],o=n[2];return isNaN(o)&&(o=0),[e,K(o*=d)*a,W(o)*a]},I=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n,e,a=(t=i(t,"lab"))[0],o=t[1],s=t[2],u=t.slice(3),l=(n=[[1.2268798758459243,-.5578149944602171,.2813910456659647],[-.0405757452148008,1.112286803280317,-.0717110580655164],[-.0763729366746601,-.4214933324022432,1.5869240198367816]],e=Z([[1,.3963377773761749,.2158037573099136],[1,-.1055613458156586,-.0638541728258133],[1,-.0894841775298119,-1.2914855480194092]],[a,o,s]),Z(n,e.map((function(t){return Math.pow(t,3)})))),c=l[0],h=l[1],f=l[2],d=L(c,h,f);return[d[0],d[1],d[2]].concat(u.length>0&&u[0]<1?[u[0]]:[])};var P=/^rgb\(\s*(-?\d+) \s*(-?\d+)\s* \s*(-?\d+)\s*\)$/,S=/^rgb\(\s*(-?\d+),\s*(-?\d+)\s*,\s*(-?\d+)\s*\)$/,q=/^rgba?\(\s*(-?\d+) \s*(-?\d+)\s* \s*(-?\d+)\s*\/\s*([01]|[01]?\.\d+)\)$/,T=/^rgba\(\s*(-?\d+),\s*(-?\d+)\s*,\s*(-?\d+)\s*,\s*([01]|[01]?\.\d+)\)$/,D=/^rgb\(\s*(-?\d+(?:\.\d+)?)% \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\)$/,U=/^rgb\(\s*(-?\d+(?:\.\d+)?)%,\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*\)$/,z=/^rgba?\(\s*(-?\d+(?:\.\d+)?)% \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\/\s*([01]|[01]?\.\d+)\)$/,H=/^rgba\(\s*(-?\d+(?:\.\d+)?)%,\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*,\s*([01]|[01]?\.\d+)\)$/,J=/^hsl\(\s*(-?\d+(?:\.\d+)?)deg \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\)$/,Q=/^hsl\(\s*(-?\d+(?:\.\d+)?),\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*\)$/,V=/^hsla?\(\s*(-?\d+(?:\.\d+)?)deg \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\/\s*([01]|[01]?\.\d+)\)$/,tt=/^hsla\(\s*(-?\d+(?:\.\d+)?),\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*,\s*([01]|[01]?\.\d+)\)$/,rt=/^lab\(\s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,nt=/^lch\(\s*(-?\d+(?:\.\d+)?%?) \s*((?:-?\d+(?:\.\d+)?%?)|none) \s*(-?\d+(?:\.\d+)?(?:deg)?|none)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,et=/^oklab\(\s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,at=/^oklch\(\s*(-?\d+(?:\.\d+)?%?) \s*(?:(-?\d+(?:\.\d+)?%?)|none) \s*(-?\d+(?:\.\d+)?(?:deg)?|none)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,ot=Math.round,it=function(r){return r.map((function(r,n){return n<=2?t(ot(r),0,255):r}))},st=function(t,r,n,e){return void 0===r&&(r=0),void 0===n&&(n=100),void 0===e&&(e=!1),"string"==typeof t&&t.endsWith("%")&&(t=parseFloat(t.substring(0,t.length-1))/100,t=e?r+.5*(t+1)*(n-r):r+t*(n-r)),+t},ut=function(t,r){return"none"===t?r:t},lt=function(t){var r;if(t=t.toLowerCase().trim(),m.format.named)try{return m.format.named(t)}catch(t){}if((r=t.match(P))||(r=t.match(S))){for(var n=r.slice(1,4),e=0;e<3;e++)n[e]=+n[e];return n[3]=1,n}if((r=t.match(q))||(r=t.match(T))){for(var a=r.slice(1,5),o=0;o<4;o++)a[o]=+a[o];return a}if((r=t.match(D))||(r=t.match(U))){for(var s=r.slice(1,4),u=0;u<3;u++)s[u]=ot(2.55*s[u]);return s[3]=1,s}if((r=t.match(z))||(r=t.match(H))){for(var l=r.slice(1,5),c=0;c<3;c++)l[c]=ot(2.55*l[c]);return l[3]=+l[3],l}if((r=t.match(J))||(r=t.match(Q))){var h=r.slice(1,4);h[1]*=.01,h[2]*=.01;for(var f=B(h),d=0;d<3;d++)f[d]=ot(f[d]);return f[3]=1,f}if((r=t.match(V))||(r=t.match(tt))){var g=r.slice(1,4);g[1]*=.01,g[2]*=.01;for(var p=B(g),v=0;v<3;v++)p[v]=ot(p[v]);return p[3]=+r[4],p}if(r=t.match(rt)){var b=r.slice(1,4);b[0]=st(b[0],0,100),b[1]=st(b[1],-125,125,!0),b[2]=st(b[2],-125,125,!0);var y=k();M("d50");var w=it(C(b));return M(y),w[3]=void 0!==r[4]?+r[4]:1,w}if(r=t.match(nt)){var x=r.slice(1,4);x[0]=st(x[0],0,100),x[1]=st(ut(x[1],0),0,150,!1),x[2]=+ut(x[2].replace("deg",""),0);var _=k();M("d50");var A=it(function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=(t=i(t,"lch"))[0],e=t[1],a=t[2],o=G(n,e,a),s=o[0],u=o[1],l=o[2],c=C(s,u,l);return[c[0],c[1],c[2],t.length>3?t[3]:1]}(x));return M(_),A[3]=void 0!==r[4]?+r[4]:1,A}if(r=t.match(et)){var j=r.slice(1,4);j[0]=st(j[0],0,1),j[1]=st(j[1],-.4,.4,!0),j[2]=st(j[2],-.4,.4,!0);var $=it(I(j));return $[3]=void 0!==r[4]?+r[4]:1,$}if(r=t.match(at)){var F=r.slice(1,4);F[0]=st(F[0],0,1),F[1]=st(ut(F[1],0),0,.4,!1),F[2]=+ut(F[2].replace("deg",""),0);var X=it(function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=(t=i(t,"lch"))[0],e=t[1],a=t[2],o=t.slice(3),s=G(n,e,a),u=s[0],l=s[1],c=s[2],h=I(u,l,c);return[h[0],h[1],h[2]].concat(o.length>0&&o[0]<1?[o[0]]:[])}(F));return X[3]=void 0!==r[4]?+r[4]:1,X}};lt.test=function(t){return P.test(t)||q.test(t)||D.test(t)||z.test(t)||J.test(t)||V.test(t)||rt.test(t)||nt.test(t)||et.test(t)||at.test(t)||S.test(t)||T.test(t)||U.test(t)||H.test(t)||Q.test(t)||tt.test(t)},p.prototype.css=function(t){return N(this._rgb,t)};var ct=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t,["css"])))};v.css=ct,m.format.css=lt,m.autodetect.push({p:5,test:function(t){for(var r=[],n=arguments.length-1;n-- >0;)r[n]=arguments[n+1];if(!r.length&&"string"===o(t)&&lt.test(t))return"css"}});var ht=/^#?([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$/,ft=/^#?([A-Fa-f0-9]{8}|[A-Fa-f0-9]{4})$/,dt=Math.round;p.prototype.hex=function(t){return function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"rgba"),e=n[0],a=n[1],o=n[2],u=n[3],l=s(t)||"auto";void 0===u&&(u=1),"auto"===l&&(l=u<1?"rgba":"rgb");var c="000000"+((e=dt(e))<<16|(a=dt(a))<<8|(o=dt(o))).toString(16);c=c.substr(c.length-6);var h="0"+dt(255*u).toString(16);switch(h=h.substr(h.length-2),l.toLowerCase()){case"rgba":return"#"+c+h;case"argb":return"#"+h+c;default:return"#"+c}}(this._rgb,t)};var gt=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t,["hex"])))};v.hex=gt,m.format.hex=function(t){if(t.match(ht)){4!==t.length&&7!==t.length||(t=t.substr(1)),3===t.length&&(t=(t=t.split(""))[0]+t[0]+t[1]+t[1]+t[2]+t[2]);var r=parseInt(t,16);return[r>>16,r>>8&255,255&r,1]}if(t.match(ft)){5!==t.length&&9!==t.length||(t=t.substr(1)),4===t.length&&(t=(t=t.split(""))[0]+t[0]+t[1]+t[1]+t[2]+t[2]+t[3]+t[3]);var n=parseInt(t,16);return[n>>24&255,n>>16&255,n>>8&255,Math.round((255&n)/255*100)/100]}throw new Error("unknown hex color: "+t)},m.autodetect.push({p:4,test:function(t){for(var r=[],n=arguments.length-1;n-- >0;)r[n]=arguments[n+1];if(!r.length&&"string"===o(t)&&[3,4,5,6,7,8,9].indexOf(t.length)>=0)return"hex"}}),p.prototype.hsl=function(){return b(this._rgb)};var mt=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t,["hsl"])))};v.hsl=mt,m.format.hsl=B,m.autodetect.push({p:2,test:function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];if("array"===o(t=i(t,"hsl"))&&3===t.length)return"hsl"}}),p.prototype.lab=function(){return x(this._rgb)};var pt=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t,["lab"])))};Object.assign(v,{lab:pt,getLabWhitePoint:k,setLabWhitePoint:M}),m.format.lab=C,m.autodetect.push({p:2,test:function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];if("array"===o(t=i(t,"lab"))&&3===t.length)return"lab"}}),p.prototype.oklab=function(){return E(this._rgb)};var vt=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t,["oklab"])))};Object.assign(v,{oklab:vt}),m.format.oklab=I,m.autodetect.push({p:2,test:function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];if("array"===o(t=i(t,"oklab"))&&3===t.length)return"oklab"}});var bt=Math.round;p.prototype.rgb=function(t){return void 0===t&&(t=!0),!1===t?this._rgb.slice(0,3):this._rgb.slice(0,3).map(bt)},p.prototype.rgba=function(t){return void 0===t&&(t=!0),this._rgb.slice(0,4).map((function(r,n){return n<3?!1===t?r:bt(r):r}))};var yt=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];return new(Function.prototype.bind.apply(p,[null].concat(t,["rgb"])))};Object.assign(v,{rgb:yt}),m.format.rgb=function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];var n=i(t,"rgba");return void 0===n[3]&&(n[3]=1),n},m.autodetect.push({p:3,test:function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];if("array"===o(t=i(t,"rgba"))&&(3===t.length||4===t.length&&"number"==o(t[3])&&t[3]>=0&&t[3]<=1))return"rgb"}}),p.prototype.alpha=function(t,r){return void 0===r&&(r=!1),void 0!==t&&"number"===o(t)?r?(this._rgb[3]=t,this):new p([this._rgb[0],this._rgb[1],this._rgb[2],t],"rgb"):this._rgb[3]},p.prototype.darken=function(t){void 0===t&&(t=1);var r=this.lab();return r[0]-=y.Kn*t,new p(r,"lab").alpha(this.alpha(),!0)},p.prototype.brighten=function(t){return void 0===t&&(t=1),this.darken(-t)},p.prototype.darker=p.prototype.darken,p.prototype.brighter=p.prototype.brighten,p.prototype.get=function(t){var r=t.split("."),n=r[0],e=r[1],a=this[n]();if(e){var o=n.indexOf(e)-("ok"===n.substr(0,2)?2:0);if(o>-1)return a[o];throw new Error("unknown channel "+e+" in mode "+n)}return a};var wt={};function Mt(t,r,n){void 0===n&&(n=.5);for(var e=[],a=arguments.length-3;a-- >0;)e[a]=arguments[a+3];var i=e[0]||"lrgb";if(wt[i]||e.length||(i=Object.keys(wt)[0]),!wt[i])throw new Error("interpolation mode "+i+" is not defined");return"object"!==o(t)&&(t=new p(t)),"object"!==o(r)&&(r=new p(r)),wt[i](t,r,n).alpha(t.alpha()+n*(r.alpha()-t.alpha()))}p.prototype.mix=p.prototype.interpolate=function(t,r){void 0===r&&(r=.5);for(var n=[],e=arguments.length-2;e-- >0;)n[e]=arguments[e+2];return Mt.apply(void 0,[this,t,r].concat(n))},p.prototype.set=function(t,r,n){void 0===n&&(n=!1);var e=t.split("."),a=e[0],i=e[1],s=this[a]();if(i){var u=a.indexOf(i)-("ok"===a.substr(0,2)?2:0);if(u>-1){if("string"==o(r))switch(r.charAt(0)){case"+":case"-":s[u]+=+r;break;case"*":s[u]*=+r.substr(1);break;case"/":s[u]/=+r.substr(1);break;default:s[u]=+r}else{if("number"!==o(r))throw new Error("unsupported value for Color.set");s[u]=r}var l=new p(s,a);return n?(this._rgb=l._rgb,this):l}throw new Error("unknown channel "+i+" in mode "+a)}return s},p.prototype.tint=function(t){void 0===t&&(t=.5);for(var r=[],n=arguments.length-1;n-- >0;)r[n]=arguments[n+1];return Mt.apply(void 0,[this,"white",t].concat(r))},p.prototype.shade=function(t){void 0===t&&(t=.5);for(var r=[],n=arguments.length-1;n-- >0;)r[n]=arguments[n+1];return Mt.apply(void 0,[this,"black",t].concat(r))};var kt=Math.sqrt,xt=Math.pow;wt.lrgb=function(t,r,n){var e=t._rgb,a=e[0],o=e[1],i=e[2],s=r._rgb,u=s[0],l=s[1],c=s[2];return new p(kt(xt(a,2)*(1-n)+xt(u,2)*n),kt(xt(o,2)*(1-n)+xt(l,2)*n),kt(xt(i,2)*(1-n)+xt(c,2)*n),"rgb")};return wt.oklab=function(t,r,n){var e=t.oklab(),a=r.oklab();return new p(e[0]+n*(a[0]-e[0]),e[1]+n*(a[1]-e[1]),e[2]+n*(a[2]-e[2]),"oklab")},Object.assign(v,{Color:p,valid:function(){for(var t=[],r=arguments.length;r--;)t[r]=arguments[r];try{return new(Function.prototype.bind.apply(p,[null].concat(t))),!0}catch(t){return!1}},css:ct,hex:gt,hsl:mt,lab:pt,oklab:vt,rgb:yt,mix:Mt,interpolate:Mt}),v}));
