/**
 * chroma.js - JavaScript library for color conversions
 *
 * Copyright (c) 2011-2024, Gregor Aisch
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name Gregor Aisch may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL GREGOR AISCH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * -------------------------------------------------------
 *
 * chroma.js includes colors from colorbrewer2.org, which are released under
 * the following license:
 *
 * Copyright (c) 2002 Cynthia Brewer, Mark Harrower,
 * and The Pennsylvania State University.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * ------------------------------------------------------
 *
 * Named colors are taken from X11 Color Names.
 * http://www.w3.org/TR/css3-color/#svg-color
 *
 * @preserve
 */

!function(r,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(r="undefined"!=typeof globalThis?globalThis:r||self).chroma=t()}(this,(function(){"use strict";function r(r,t,n){return void 0===t&&(t=0),void 0===n&&(n=1),l(s(t,r),n)}function t(t){t._clipped=!1,t._unclipped=t.slice(0);for(var n=0;n<=3;n++)n<3?((t[n]<0||t[n]>255)&&(t._clipped=!0),t[n]=r(t[n],0,255)):3===n&&(t[n]=r(t[n],0,1));return t}for(var n={},e=0,a=["Boolean","Number","String","Function","Array","Date","RegExp","Undefined","Null"];e<a.length;e+=1){var f=a[e];n["[object "+f+"]"]=f.toLowerCase()}function o(r){return n[Object.prototype.toString.call(r)]||"object"}function u(r,t){return void 0===t&&(t=null),r.length>=3?Array.prototype.slice.call(r):"object"==o(r[0])&&t?t.split("").filter((function(t){return void 0!==r[0][t]})).map((function(t){return r[0][t]})):r[0].slice(0)}function c(r){if(r.length<2)return null;var t=r.length-1;return"string"==o(r[t])?r[t].toLowerCase():null}var i=Math.PI,l=Math.min,s=Math.max,h=function(r){return Math.round(100*r)/100},d=function(r){return Math.round(100*r)/100},b=2*i,g=i/3,v=i/180,p=180/i,m={format:{},autodetect:[]},y=function(){for(var r=[],n=arguments.length;n--;)r[n]=arguments[n];var e=this;if("object"===o(r[0])&&r[0].constructor&&r[0].constructor===this.constructor)return r[0];var a=c(r),f=!1;if(!a){f=!0,m.sorted||(m.autodetect=m.autodetect.sort((function(r,t){return t.p-r.p})),m.sorted=!0);for(var u=0,i=m.autodetect;u<i.length;u+=1){var l=i[u];if(a=l.test.apply(l,r))break}}if(!m.format[a])throw new Error("unknown format: "+r);var s=m.format[a].apply(null,f?r:r.slice(0,-1));e._rgb=t(s),3===e._rgb.length&&e._rgb.push(1)};y.prototype.toString=function(){return"function"==o(this.hex)?this.hex():"["+this._rgb.join(",")+"]"};var w=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r)))};w.version="3.0.0";var k=Math.max;y.prototype.cmyk=function(){return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgb"),e=n[0],a=n[1],f=n[2],o=1-k(e/=255,k(a/=255,f/=255)),c=o<1?1/(1-o):0;return[(1-e-o)*c,(1-a-o)*c,(1-f-o)*c,o]}(this._rgb)};var M=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["cmyk"])))};Object.assign(w,{cmyk:M}),m.format.cmyk=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=(r=u(r,"cmyk"))[0],e=r[1],a=r[2],f=r[3],o=r.length>4?r[4]:1;return 1===f?[0,0,0,o]:[n>=1?0:255*(1-n)*(1-f),e>=1?0:255*(1-e)*(1-f),a>=1?0:255*(1-a)*(1-f),o]},m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"cmyk"))&&4===r.length)return"cmyk"}});var N=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n,e,a=(r=u(r,"rgba"))[0],f=r[1],o=r[2],c=l(a/=255,f/=255,o/=255),i=s(a,f,o),h=(i+c)/2;return i===c?(n=0,e=Number.NaN):n=h<.5?(i-c)/(i+c):(i-c)/(2-i-c),a==i?e=(f-o)/(i-c):f==i?e=2+(o-a)/(i-c):o==i&&(e=4+(a-f)/(i-c)),(e*=60)<0&&(e+=360),r.length>3&&void 0!==r[3]?[e,n,h,r[3]]:[e,n,h]},_={Kn:18,labWhitePoint:"d65",Xn:.95047,Yn:1,Zn:1.08883,t0:.137931034,t1:.206896552,t2:.12841855,t3:.008856452,kE:216/24389,kKE:8,kK:24389/27,RefWhiteRGB:{X:.95047,Y:1,Z:1.08883},MtxRGB2XYZ:{m00:.4124564390896922,m01:.21267285140562253,m02:.0193338955823293,m10:.357576077643909,m11:.715152155287818,m12:.11919202588130297,m20:.18043748326639894,m21:.07217499330655958,m22:.9503040785363679},MtxXYZ2RGB:{m00:3.2404541621141045,m01:-.9692660305051868,m02:.055643430959114726,m10:-1.5371385127977166,m11:1.8760108454466942,m12:-.2040259135167538,m20:-.498531409556016,m21:.041556017530349834,m22:1.0572251882231791},As:.9414285350000001,Bs:1.040417467,Cs:1.089532651,MtxAdaptMa:{m00:.8951,m01:-.7502,m02:.0389,m10:.2664,m11:1.7135,m12:-.0685,m20:-.1614,m21:.0367,m22:1.0296},MtxAdaptMaI:{m00:.9869929054667123,m01:.43230526972339456,m02:-.008528664575177328,m10:-.14705425642099013,m11:.5183602715367776,m12:.04004282165408487,m20:.15996265166373125,m21:.0492912282128556,m22:.9684866957875502}},x=new Map([["a",[1.0985,.35585]],["b",[1.0985,.35585]],["c",[.98074,1.18232]],["d50",[.96422,.82521]],["d55",[.95682,.92149]],["d65",[.95047,1.08883]],["e",[1,1,1]],["f2",[.99186,.67393]],["f7",[.95041,1.08747]],["f11",[1.00962,.6435]],["icc",[.96422,.82521]]]);function A(r){var t=x.get(String(r).toLowerCase());if(!t)throw new Error("unknown Lab illuminant "+r);_.labWhitePoint=r,_.Xn=t[0],_.Zn=t[1]}function j(){return _.labWhitePoint}var E=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgb"),e=n[0],a=n[1],f=n[2],o=n.slice(3),c=F(e,a,f),i=function(r,t,n){var e=_.Xn,a=_.Yn,f=_.Zn,o=_.kE,u=_.kK,c=r/e,i=t/a,l=n/f,s=c>o?Math.pow(c,1/3):(u*c+16)/116,h=i>o?Math.pow(i,1/3):(u*i+16)/116,d=l>o?Math.pow(l,1/3):(u*l+16)/116;return[116*h-16,500*(s-h),200*(h-d)]}(c[0],c[1],c[2]);return[i[0],i[1],i[2]].concat(o.length>0&&o[0]<1?[o[0]]:[])};function O(r){var t=Math.sign(r);return((r=Math.abs(r))<=.04045?r/12.92:Math.pow((r+.055)/1.055,2.4))*t}var F=function(r,t,n){r=O(r/255),t=O(t/255),n=O(n/255);var e=_.MtxRGB2XYZ,a=_.MtxAdaptMa,f=_.MtxAdaptMaI,o=_.Xn,u=_.Yn,c=_.Zn,i=_.As,l=_.Bs,s=_.Cs,h=r*e.m00+t*e.m10+n*e.m20,d=r*e.m01+t*e.m11+n*e.m21,b=r*e.m02+t*e.m12+n*e.m22,g=o*a.m00+u*a.m10+c*a.m20,v=o*a.m01+u*a.m11+c*a.m21,p=o*a.m02+u*a.m12+c*a.m22,m=h*a.m00+d*a.m10+b*a.m20,y=h*a.m01+d*a.m11+b*a.m21,w=h*a.m02+d*a.m12+b*a.m22;return y*=v/l,w*=p/s,[h=(m*=g/i)*f.m00+y*f.m10+w*f.m20,d=m*f.m01+y*f.m11+w*f.m21,b=m*f.m02+y*f.m12+w*f.m22]},L=Math.sqrt,P=Math.atan2,B=Math.round,G=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"lab"),e=n[0],a=n[1],f=n[2],o=L(a*a+f*f),c=(P(f,a)*p+360)%360;return 0===B(1e4*o)&&(c=Number.NaN),[e,o,c]},R=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgb"),e=n[0],a=n[1],f=n[2],o=n.slice(3),c=E(e,a,f),i=c[0],l=c[1],s=c[2],h=G(i,l,s);return[h[0],h[1],h[2]].concat(o.length>0&&o[0]<1?[o[0]]:[])};function Y(r,t){var n=r.length;Array.isArray(r[0])||(r=[r]),Array.isArray(t[0])||(t=t.map((function(r){return[r]})));var e=t[0].length,a=t[0].map((function(r,n){return t.map((function(r){return r[n]}))})),f=r.map((function(r){return a.map((function(t){return Array.isArray(r)?r.reduce((function(r,n,e){return r+n*(t[e]||0)}),0):t.reduce((function(t,n){return t+n*r}),0)}))}));return 1===n&&(f=f[0]),1===e?f.map((function(r){return r[0]})):f}var $=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n,e,a=u(r,"rgb"),f=a[0],o=a[1],c=a[2],i=a.slice(3),l=F(f,o,c);return(n=[[.210454268309314,.7936177747023054,-.0040720430116193],[1.9779985324311684,-2.42859224204858,.450593709617411],[.0259040424655478,.7827717124575296,-.8086757549230774]],e=Y([[.819022437996703,.3619062600528904,-.1288737815209879],[.0329836539323885,.9292868615863434,.0361446663506424],[.0481771893596242,.2642395317527308,.6335478284694309]],l),Y(n,e.map((function(r){return Math.cbrt(r)})))).concat(i.length>0&&i[0]<1?[i[0]]:[])};var q=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgb"),e=n[0],a=n[1],f=n[2],o=n.slice(3),c=$(e,a,f),i=c[0],l=c[1],s=c[2],h=G(i,l,s);return[h[0],h[1],h[2]].concat(o.length>0&&o[0]<1?[o[0]]:[])},X=Math.round,C=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgba"),e=c(r)||"rgb";if("hsl"===e.substr(0,3))return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"hsla"),e=c(r)||"lsa";return n[0]=h(n[0]||0)+"deg",n[1]=h(100*n[1])+"%",n[2]=h(100*n[2])+"%","hsla"===e||n.length>3&&n[3]<1?(n[3]="/ "+(n.length>3?n[3]:1),e="hsla"):n.length=3,e.substr(0,3)+"("+n.join(" ")+")"}(N(n),e);if("lab"===e.substr(0,3)){var a=j();A("d50");var f=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"lab"),e=c(r)||"lab";return n[0]=h(n[0])+"%",n[1]=h(n[1]),n[2]=h(n[2]),"laba"===e||n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"lab("+n.join(" ")+")"}(E(n),e);return A(a),f}if("lch"===e.substr(0,3)){var o=j();A("d50");var i=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"lch"),e=c(r)||"lab";return n[0]=h(n[0])+"%",n[1]=h(n[1]),n[2]=h(n[2])+"deg","lcha"===e||n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"lch("+n.join(" ")+")"}(R(n),e);return A(o),i}return"oklab"===e.substr(0,5)?function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"lab");return n[0]=h(100*n[0])+"%",n[1]=d(n[1]),n[2]=d(n[2]),n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"oklab("+n.join(" ")+")"}($(n)):"oklch"===e.substr(0,5)?function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"lab");return n[0]=h(100*n[0])+"%",n[1]=d(n[1]),n[2]=h(n[2])+"deg",n.length>3&&n[3]<1?n[3]="/ "+(n.length>3?n[3]:1):n.length=3,"oklch("+n.join(" ")+")"}(q(n)):(n[0]=X(n[0]),n[1]=X(n[1]),n[2]=X(n[2]),("rgba"===e||n.length>3&&n[3]<1)&&(n[3]="/ "+(n.length>3?n[3]:1),e="rgba"),e.substr(0,3)+"("+n.slice(0,"rgb"===e?3:4).join(" ")+")")},Z=function(){for(var r,t=[],n=arguments.length;n--;)t[n]=arguments[n];var e,a,f,o=(t=u(t,"hsl"))[0],c=t[1],i=t[2];if(0===c)e=a=f=255*i;else{var l=[0,0,0],s=[0,0,0],h=i<.5?i*(1+c):i+c-i*c,d=2*i-h,b=o/360;l[0]=b+1/3,l[1]=b,l[2]=b-1/3;for(var g=0;g<3;g++)l[g]<0&&(l[g]+=1),l[g]>1&&(l[g]-=1),6*l[g]<1?s[g]=d+6*(h-d)*l[g]:2*l[g]<1?s[g]=h:3*l[g]<2?s[g]=d+(h-d)*(2/3-l[g])*6:s[g]=d;e=(r=[255*s[0],255*s[1],255*s[2]])[0],a=r[1],f=r[2]}return t.length>3?[e,a,f,t[3]]:[e,a,f,1]},S=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=(r=u(r,"lab"))[0],e=r[1],a=r[2],f=W(n,e,a),o=f[0],c=f[1],i=f[2],l=K(o,c,i);return[l[0],l[1],l[2],r.length>3?r[3]:1]},W=function(r,t,n){var e=_.kE,a=_.kK,f=_.kKE,o=_.Xn,u=_.Yn,c=_.Zn,i=(r+16)/116,l=.002*t+i,s=i-.005*n,h=l*l*l,d=s*s*s;return[(h>e?h:(116*l-16)/a)*o,(r>f?Math.pow((r+16)/116,3):r/a)*u,(d>e?d:(116*s-16)/a)*c]},I=function(r){var t=Math.sign(r);return((r=Math.abs(r))<=.0031308?12.92*r:1.055*Math.pow(r,1/2.4)-.055)*t},K=function(r,t,n){var e=_.MtxAdaptMa,a=_.MtxAdaptMaI,f=_.MtxXYZ2RGB,o=_.RefWhiteRGB,u=_.Xn,c=_.Yn,i=_.Zn,l=u*e.m00+c*e.m10+i*e.m20,s=u*e.m01+c*e.m11+i*e.m21,h=u*e.m02+c*e.m12+i*e.m22,d=o.X*e.m00+o.Y*e.m10+o.Z*e.m20,b=o.X*e.m01+o.Y*e.m11+o.Z*e.m21,g=o.X*e.m02+o.Y*e.m12+o.Z*e.m22,v=(r*e.m00+t*e.m10+n*e.m20)*(d/l),p=(r*e.m01+t*e.m11+n*e.m21)*(b/s),m=(r*e.m02+t*e.m12+n*e.m22)*(g/h),y=v*a.m00+p*a.m10+m*a.m20,w=v*a.m01+p*a.m11+m*a.m21,k=v*a.m02+p*a.m12+m*a.m22;return[255*I(y*f.m00+w*f.m10+k*f.m20),255*I(y*f.m01+w*f.m11+k*f.m21),255*I(y*f.m02+w*f.m12+k*f.m22)]},z=Math.sin,U=Math.cos,V=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"lch"),e=n[0],a=n[1],f=n[2];return isNaN(f)&&(f=0),[e,U(f*=v)*a,z(f)*a]},D=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=(r=u(r,"lch"))[0],e=r[1],a=r[2],f=V(n,e,a),o=f[0],c=f[1],i=f[2],l=S(o,c,i);return[l[0],l[1],l[2],r.length>3?r[3]:1]},T=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n,e,a=(r=u(r,"lab"))[0],f=r[1],o=r[2],c=r.slice(3),i=(n=[[1.2268798758459243,-.5578149944602171,.2813910456659647],[-.0405757452148008,1.112286803280317,-.0717110580655164],[-.0763729366746601,-.4214933324022432,1.5869240198367816]],e=Y([[1,.3963377773761749,.2158037573099136],[1,-.1055613458156586,-.0638541728258133],[1,-.0894841775298119,-1.2914855480194092]],[a,f,o]),Y(n,e.map((function(r){return Math.pow(r,3)})))),l=i[0],s=i[1],h=i[2],d=K(l,s,h);return[d[0],d[1],d[2]].concat(c.length>0&&c[0]<1?[c[0]]:[])};var H=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=(r=u(r,"lch"))[0],e=r[1],a=r[2],f=r.slice(3),o=V(n,e,a),c=o[0],i=o[1],l=o[2],s=T(c,i,l);return[s[0],s[1],s[2]].concat(f.length>0&&f[0]<1?[f[0]]:[])},J=/^rgb\(\s*(-?\d+) \s*(-?\d+)\s* \s*(-?\d+)\s*\)$/,Q=/^rgb\(\s*(-?\d+),\s*(-?\d+)\s*,\s*(-?\d+)\s*\)$/,rr=/^rgba?\(\s*(-?\d+) \s*(-?\d+)\s* \s*(-?\d+)\s*\/\s*([01]|[01]?\.\d+)\)$/,tr=/^rgba\(\s*(-?\d+),\s*(-?\d+)\s*,\s*(-?\d+)\s*,\s*([01]|[01]?\.\d+)\)$/,nr=/^rgb\(\s*(-?\d+(?:\.\d+)?)% \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\)$/,er=/^rgb\(\s*(-?\d+(?:\.\d+)?)%,\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*\)$/,ar=/^rgba?\(\s*(-?\d+(?:\.\d+)?)% \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\/\s*([01]|[01]?\.\d+)\)$/,fr=/^rgba\(\s*(-?\d+(?:\.\d+)?)%,\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*,\s*([01]|[01]?\.\d+)\)$/,or=/^hsl\(\s*(-?\d+(?:\.\d+)?)deg \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\)$/,ur=/^hsl\(\s*(-?\d+(?:\.\d+)?),\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*\)$/,cr=/^hsla?\(\s*(-?\d+(?:\.\d+)?)deg \s*(-?\d+(?:\.\d+)?)%\s* \s*(-?\d+(?:\.\d+)?)%\s*\/\s*([01]|[01]?\.\d+)\)$/,ir=/^hsla\(\s*(-?\d+(?:\.\d+)?),\s*(-?\d+(?:\.\d+)?)%\s*,\s*(-?\d+(?:\.\d+)?)%\s*,\s*([01]|[01]?\.\d+)\)$/,lr=/^lab\(\s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,sr=/^lch\(\s*(-?\d+(?:\.\d+)?%?) \s*((?:-?\d+(?:\.\d+)?%?)|none) \s*(-?\d+(?:\.\d+)?(?:deg)?|none)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,hr=/^oklab\(\s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?) \s*(-?\d+(?:\.\d+)?%?)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,dr=/^oklch\(\s*(-?\d+(?:\.\d+)?%?) \s*(?:(-?\d+(?:\.\d+)?%?)|none) \s*(-?\d+(?:\.\d+)?(?:deg)?|none)\s*(?:\/\s*(\d+(?:\.\d+)?))?\)?$/,br=Math.round,gr=function(t){return t.map((function(t,n){return n<=2?r(br(t),0,255):t}))},vr=function(r,t,n,e){return void 0===t&&(t=0),void 0===n&&(n=100),void 0===e&&(e=!1),"string"==typeof r&&r.endsWith("%")&&(r=parseFloat(r.substring(0,r.length-1))/100,r=e?t+.5*(r+1)*(n-t):t+r*(n-t)),+r},pr=function(r,t){return"none"===r?t:r},mr=function(r){var t;if(r=r.toLowerCase().trim(),m.format.named)try{return m.format.named(r)}catch(r){}if((t=r.match(J))||(t=r.match(Q))){for(var n=t.slice(1,4),e=0;e<3;e++)n[e]=+n[e];return n[3]=1,n}if((t=r.match(rr))||(t=r.match(tr))){for(var a=t.slice(1,5),f=0;f<4;f++)a[f]=+a[f];return a}if((t=r.match(nr))||(t=r.match(er))){for(var o=t.slice(1,4),u=0;u<3;u++)o[u]=br(2.55*o[u]);return o[3]=1,o}if((t=r.match(ar))||(t=r.match(fr))){for(var c=t.slice(1,5),i=0;i<3;i++)c[i]=br(2.55*c[i]);return c[3]=+c[3],c}if((t=r.match(or))||(t=r.match(ur))){var l=t.slice(1,4);l[1]*=.01,l[2]*=.01;for(var s=Z(l),h=0;h<3;h++)s[h]=br(s[h]);return s[3]=1,s}if((t=r.match(cr))||(t=r.match(ir))){var d=t.slice(1,4);d[1]*=.01,d[2]*=.01;for(var b=Z(d),g=0;g<3;g++)b[g]=br(b[g]);return b[3]=+t[4],b}if(t=r.match(lr)){var v=t.slice(1,4);v[0]=vr(v[0],0,100),v[1]=vr(v[1],-125,125,!0),v[2]=vr(v[2],-125,125,!0);var p=j();A("d50");var y=gr(S(v));return A(p),y[3]=void 0!==t[4]?+t[4]:1,y}if(t=r.match(sr)){var w=t.slice(1,4);w[0]=vr(w[0],0,100),w[1]=vr(pr(w[1],0),0,150,!1),w[2]=+pr(w[2].replace("deg",""),0);var k=j();A("d50");var M=gr(D(w));return A(k),M[3]=void 0!==t[4]?+t[4]:1,M}if(t=r.match(hr)){var N=t.slice(1,4);N[0]=vr(N[0],0,1),N[1]=vr(N[1],-.4,.4,!0),N[2]=vr(N[2],-.4,.4,!0);var _=gr(T(N));return _[3]=void 0!==t[4]?+t[4]:1,_}if(t=r.match(dr)){var x=t.slice(1,4);x[0]=vr(x[0],0,1),x[1]=vr(pr(x[1],0),0,.4,!1),x[2]=+pr(x[2].replace("deg",""),0);var E=gr(H(x));return E[3]=void 0!==t[4]?+t[4]:1,E}};mr.test=function(r){return J.test(r)||rr.test(r)||nr.test(r)||ar.test(r)||or.test(r)||cr.test(r)||lr.test(r)||sr.test(r)||hr.test(r)||dr.test(r)||Q.test(r)||tr.test(r)||er.test(r)||fr.test(r)||ur.test(r)||ir.test(r)},y.prototype.css=function(r){return C(this._rgb,r)};var yr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["css"])))};w.css=yr,m.format.css=mr,m.autodetect.push({p:5,test:function(r){for(var t=[],n=arguments.length-1;n-- >0;)t[n]=arguments[n+1];if(!t.length&&"string"===o(r)&&mr.test(r))return"css"}}),m.format.gl=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgba");return n[0]*=255,n[1]*=255,n[2]*=255,n};var wr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["gl"])))};w.gl=wr,y.prototype.gl=function(){var r=this._rgb;return[r[0]/255,r[1]/255,r[2]/255,r[3]]};var kr=Math.floor;y.prototype.hcg=function(){return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n,e=u(r,"rgb"),a=e[0],f=e[1],o=e[2],c=l(a,f,o),i=s(a,f,o),h=i-c,d=100*h/255,b=c/(255-h)*100;return 0===h?n=Number.NaN:(a===i&&(n=(f-o)/h),f===i&&(n=2+(o-a)/h),o===i&&(n=4+(a-f)/h),(n*=60)<0&&(n+=360)),[n,d,b]}(this._rgb)};var Mr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["hcg"])))};w.hcg=Mr,m.format.hcg=function(){for(var r,t,n,e,a,f,o=[],c=arguments.length;c--;)o[c]=arguments[c];var i,l,s,h=(o=u(o,"hcg"))[0],d=o[1],b=o[2];b*=255;var g=255*d;if(0===d)i=l=s=b;else{360===h&&(h=0),h>360&&(h-=360),h<0&&(h+=360);var v=kr(h/=60),p=h-v,m=b*(1-d),y=m+g*(1-p),w=m+g*p,k=m+g;switch(v){case 0:i=(r=[k,w,m])[0],l=r[1],s=r[2];break;case 1:i=(t=[y,k,m])[0],l=t[1],s=t[2];break;case 2:i=(n=[m,k,w])[0],l=n[1],s=n[2];break;case 3:i=(e=[m,y,k])[0],l=e[1],s=e[2];break;case 4:i=(a=[w,m,k])[0],l=a[1],s=a[2];break;case 5:i=(f=[k,m,y])[0],l=f[1],s=f[2]}}return[i,l,s,o.length>3?o[3]:1]},m.autodetect.push({p:1,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"hcg"))&&3===r.length)return"hcg"}});var Nr=/^#?([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$/,_r=/^#?([A-Fa-f0-9]{8}|[A-Fa-f0-9]{4})$/,xr=function(r){if(r.match(Nr)){4!==r.length&&7!==r.length||(r=r.substr(1)),3===r.length&&(r=(r=r.split(""))[0]+r[0]+r[1]+r[1]+r[2]+r[2]);var t=parseInt(r,16);return[t>>16,t>>8&255,255&t,1]}if(r.match(_r)){5!==r.length&&9!==r.length||(r=r.substr(1)),4===r.length&&(r=(r=r.split(""))[0]+r[0]+r[1]+r[1]+r[2]+r[2]+r[3]+r[3]);var n=parseInt(r,16);return[n>>24&255,n>>16&255,n>>8&255,Math.round((255&n)/255*100)/100]}throw new Error("unknown hex color: "+r)},Ar=Math.round,jr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgba"),e=n[0],a=n[1],f=n[2],o=n[3],i=c(r)||"auto";void 0===o&&(o=1),"auto"===i&&(i=o<1?"rgba":"rgb");var l="000000"+((e=Ar(e))<<16|(a=Ar(a))<<8|(f=Ar(f))).toString(16);l=l.substr(l.length-6);var s="0"+Ar(255*o).toString(16);switch(s=s.substr(s.length-2),i.toLowerCase()){case"rgba":return"#"+l+s;case"argb":return"#"+s+l;default:return"#"+l}};y.prototype.hex=function(r){return jr(this._rgb,r)};var Er=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["hex"])))};w.hex=Er,m.format.hex=xr,m.autodetect.push({p:4,test:function(r){for(var t=[],n=arguments.length-1;n-- >0;)t[n]=arguments[n+1];if(!t.length&&"string"===o(r)&&[3,4,5,6,7,8,9].indexOf(r.length)>=0)return"hex"}});var Or=Math.cos,Fr=Math.min,Lr=Math.sqrt,Pr=Math.acos;y.prototype.hsi=function(){return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n,e=u(r,"rgb"),a=e[0],f=e[1],o=e[2],c=Fr(a/=255,f/=255,o/=255),i=(a+f+o)/3,l=i>0?1-c/i:0;return 0===l?n=NaN:(n=(a-f+(a-o))/2,n/=Lr((a-f)*(a-f)+(a-o)*(f-o)),n=Pr(n),o>f&&(n=b-n),n/=b),[360*n,l,i]}(this._rgb)};var Br=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["hsi"])))};w.hsi=Br,m.format.hsi=function(){for(var t=[],n=arguments.length;n--;)t[n]=arguments[n];var e,a,f,o=(t=u(t,"hsi"))[0],c=t[1],i=t[2];return isNaN(o)&&(o=0),isNaN(c)&&(c=0),o>360&&(o-=360),o<0&&(o+=360),(o/=360)<1/3?a=1-((f=(1-c)/3)+(e=(1+c*Or(b*o)/Or(g-b*o))/3)):o<2/3?f=1-((e=(1-c)/3)+(a=(1+c*Or(b*(o-=1/3))/Or(g-b*o))/3)):e=1-((a=(1-c)/3)+(f=(1+c*Or(b*(o-=2/3))/Or(g-b*o))/3)),[255*(e=r(i*e*3)),255*(a=r(i*a*3)),255*(f=r(i*f*3)),t.length>3?t[3]:1]},m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"hsi"))&&3===r.length)return"hsi"}}),y.prototype.hsl=function(){return N(this._rgb)};var Gr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["hsl"])))};w.hsl=Gr,m.format.hsl=Z,m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"hsl"))&&3===r.length)return"hsl"}});var Rr=Math.floor,Yr=Math.min,$r=Math.max;y.prototype.hsv=function(){return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n,e,a,f=(r=u(r,"rgb"))[0],o=r[1],c=r[2],i=Yr(f,o,c),l=$r(f,o,c),s=l-i;return a=l/255,0===l?(n=Number.NaN,e=0):(e=s/l,f===l&&(n=(o-c)/s),o===l&&(n=2+(c-f)/s),c===l&&(n=4+(f-o)/s),(n*=60)<0&&(n+=360)),[n,e,a]}(this._rgb)};var qr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["hsv"])))};w.hsv=qr,m.format.hsv=function(){for(var r,t,n,e,a,f,o=[],c=arguments.length;c--;)o[c]=arguments[c];var i,l,s,h=(o=u(o,"hsv"))[0],d=o[1],b=o[2];if(b*=255,0===d)i=l=s=b;else{360===h&&(h=0),h>360&&(h-=360),h<0&&(h+=360);var g=Rr(h/=60),v=h-g,p=b*(1-d),m=b*(1-d*v),y=b*(1-d*(1-v));switch(g){case 0:i=(r=[b,y,p])[0],l=r[1],s=r[2];break;case 1:i=(t=[m,b,p])[0],l=t[1],s=t[2];break;case 2:i=(n=[p,b,y])[0],l=n[1],s=n[2];break;case 3:i=(e=[p,m,b])[0],l=e[1],s=e[2];break;case 4:i=(a=[y,p,b])[0],l=a[1],s=a[2];break;case 5:i=(f=[b,p,m])[0],l=f[1],s=f[2]}}return[i,l,s,o.length>3?o[3]:1]},m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"hsv"))&&3===r.length)return"hsv"}}),y.prototype.lab=function(){return E(this._rgb)};var Xr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["lab"])))};Object.assign(w,{lab:Xr,getLabWhitePoint:j,setLabWhitePoint:A}),m.format.lab=S,m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"lab"))&&3===r.length)return"lab"}});y.prototype.lch=function(){return R(this._rgb)},y.prototype.hcl=function(){return R(this._rgb).reverse()};var Cr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["lch"])))},Zr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["hcl"])))};Object.assign(w,{lch:Cr,hcl:Zr}),m.format.lch=D,m.format.hcl=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"hcl").reverse();return D.apply(void 0,n)},["lch","hcl"].forEach((function(r){return m.autodetect.push({p:2,test:function(){for(var t=[],n=arguments.length;n--;)t[n]=arguments[n];if("array"===o(t=u(t,r))&&3===t.length)return r}})}));y.prototype.num=function(){return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgb");return(n[0]<<16)+(n[1]<<8)+n[2]}(this._rgb)};var Sr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["num"])))};Object.assign(w,{num:Sr}),m.format.num=function(r){if("number"==o(r)&&r>=0&&r<=16777215)return[r>>16,r>>8&255,255&r,1];throw new Error("unknown num color: "+r)},m.autodetect.push({p:5,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if(1===r.length&&"number"===o(r[0])&&r[0]>=0&&r[0]<=16777215)return"num"}});var Wr=Math.round;y.prototype.rgb=function(r){return void 0===r&&(r=!0),!1===r?this._rgb.slice(0,3):this._rgb.slice(0,3).map(Wr)},y.prototype.rgba=function(r){return void 0===r&&(r=!0),this._rgb.slice(0,4).map((function(t,n){return n<3?!1===r?t:Wr(t):t}))};var Ir=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["rgb"])))};Object.assign(w,{rgb:Ir}),m.format.rgb=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];var n=u(r,"rgba");return void 0===n[3]&&(n[3]=1),n},m.autodetect.push({p:3,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"rgba"))&&(3===r.length||4===r.length&&"number"==o(r[3])&&r[3]>=0&&r[3]<=1))return"rgb"}});var Kr=Math.log,zr=function(r){var t,n,e,a=r/100;return a<66?(t=255,n=a<6?0:-155.25485562709179-.44596950469579133*(n=a-2)+104.49216199393888*Kr(n),e=a<20?0:.8274096064007395*(e=a-10)-254.76935184120902+115.67994401066147*Kr(e)):(t=351.97690566805693+.114206453784165*(t=a-55)-40.25366309332127*Kr(t),n=325.4494125711974+.07943456536662342*(n=a-50)-28.0852963507957*Kr(n),e=255),[t,n,e,1]},Ur=Math.round;y.prototype.temp=y.prototype.kelvin=y.prototype.temperature=function(){return function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];for(var n,e=u(r,"rgb"),a=e[0],f=e[2],o=1e3,c=4e4;c-o>.4;){var i=zr(n=.5*(c+o));i[2]/i[0]>=f/a?c=n:o=n}return Ur(n)}(this._rgb)};var Vr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["temp"])))};Object.assign(w,{temp:Vr,kelvin:Vr,temperature:Vr}),m.format.temp=m.format.kelvin=m.format.temperature=zr,y.prototype.oklab=function(){return $(this._rgb)};var Dr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["oklab"])))};Object.assign(w,{oklab:Dr}),m.format.oklab=T,m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"oklab"))&&3===r.length)return"oklab"}}),y.prototype.oklch=function(){return q(this._rgb)};var Tr=function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];return new(Function.prototype.bind.apply(y,[null].concat(r,["oklch"])))};Object.assign(w,{oklch:Tr}),m.format.oklch=H,m.autodetect.push({p:2,test:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];if("array"===o(r=u(r,"oklch"))&&3===r.length)return"oklch"}});var Hr={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",laserlemon:"#ffff54",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrod:"#fafad2",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",maroon2:"#7f0000",maroon3:"#b03060",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",purple2:"#7f007f",purple3:"#a020f0",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};y.prototype.name=function(){for(var r=jr(this._rgb,"rgb"),t=0,n=Object.keys(Hr);t<n.length;t+=1){var e=n[t];if(Hr[e]===r)return e.toLowerCase()}return r},m.format.named=function(r){if(r=r.toLowerCase(),Hr[r])return xr(Hr[r]);throw new Error("unknown color name: "+r)},m.autodetect.push({p:5,test:function(r){for(var t=[],n=arguments.length-1;n-- >0;)t[n]=arguments[n+1];if(!t.length&&"string"===o(r)&&Hr[r.toLowerCase()])return"named"}}),y.prototype.alpha=function(r,t){return void 0===t&&(t=!1),void 0!==r&&"number"===o(r)?t?(this._rgb[3]=r,this):new y([this._rgb[0],this._rgb[1],this._rgb[2],r],"rgb"):this._rgb[3]},y.prototype.clipped=function(){return this._rgb._clipped||!1},y.prototype.darken=function(r){void 0===r&&(r=1);var t=this.lab();return t[0]-=_.Kn*r,new y(t,"lab").alpha(this.alpha(),!0)},y.prototype.brighten=function(r){return void 0===r&&(r=1),this.darken(-r)},y.prototype.darker=y.prototype.darken,y.prototype.brighter=y.prototype.brighten,y.prototype.get=function(r){var t=r.split("."),n=t[0],e=t[1],a=this[n]();if(e){var f=n.indexOf(e)-("ok"===n.substr(0,2)?2:0);if(f>-1)return a[f];throw new Error("unknown channel "+e+" in mode "+n)}return a};var Jr=Math.pow;y.prototype.luminance=function(r,t){if(void 0===t&&(t="rgb"),void 0!==r&&"number"===o(r)){if(0===r)return new y([0,0,0,this._rgb[3]],"rgb");if(1===r)return new y([255,255,255,this._rgb[3]],"rgb");var n=this.luminance(),e=20,a=function(n,f){var o=n.interpolate(f,.5,t),u=o.luminance();return Math.abs(r-u)<1e-7||!e--?o:u>r?a(n,o):a(o,f)},f=(n>r?a(new y([0,0,0]),this):a(this,new y([255,255,255]))).rgb();return new y(f.concat([this._rgb[3]]))}return Qr.apply(void 0,this._rgb.slice(0,3))};var Qr=function(r,t,n){return.2126*(r=rt(r))+.7152*(t=rt(t))+.0722*(n=rt(n))},rt=function(r){return(r/=255)<=.03928?r/12.92:Jr((r+.055)/1.055,2.4)},tt={};function nt(r,t,n){void 0===n&&(n=.5);for(var e=[],a=arguments.length-3;a-- >0;)e[a]=arguments[a+3];var f=e[0]||"lrgb";if(tt[f]||e.length||(f=Object.keys(tt)[0]),!tt[f])throw new Error("interpolation mode "+f+" is not defined");return"object"!==o(r)&&(r=new y(r)),"object"!==o(t)&&(t=new y(t)),tt[f](r,t,n).alpha(r.alpha()+n*(t.alpha()-r.alpha()))}y.prototype.mix=y.prototype.interpolate=function(r,t){void 0===t&&(t=.5);for(var n=[],e=arguments.length-2;e-- >0;)n[e]=arguments[e+2];return nt.apply(void 0,[this,r,t].concat(n))},y.prototype.premultiply=function(r){void 0===r&&(r=!1);var t=this._rgb,n=t[3];return r?(this._rgb=[t[0]*n,t[1]*n,t[2]*n,n],this):new y([t[0]*n,t[1]*n,t[2]*n,n],"rgb")},y.prototype.saturate=function(r){void 0===r&&(r=1);var t=this.lch();return t[1]+=_.Kn*r,t[1]<0&&(t[1]=0),new y(t,"lch").alpha(this.alpha(),!0)},y.prototype.desaturate=function(r){return void 0===r&&(r=1),this.saturate(-r)},y.prototype.set=function(r,t,n){void 0===n&&(n=!1);var e=r.split("."),a=e[0],f=e[1],u=this[a]();if(f){var c=a.indexOf(f)-("ok"===a.substr(0,2)?2:0);if(c>-1){if("string"==o(t))switch(t.charAt(0)){case"+":case"-":u[c]+=+t;break;case"*":u[c]*=+t.substr(1);break;case"/":u[c]/=+t.substr(1);break;default:u[c]=+t}else{if("number"!==o(t))throw new Error("unsupported value for Color.set");u[c]=t}var i=new y(u,a);return n?(this._rgb=i._rgb,this):i}throw new Error("unknown channel "+f+" in mode "+a)}return u},y.prototype.tint=function(r){void 0===r&&(r=.5);for(var t=[],n=arguments.length-1;n-- >0;)t[n]=arguments[n+1];return nt.apply(void 0,[this,"white",r].concat(t))},y.prototype.shade=function(r){void 0===r&&(r=.5);for(var t=[],n=arguments.length-1;n-- >0;)t[n]=arguments[n+1];return nt.apply(void 0,[this,"black",r].concat(t))};tt.rgb=function(r,t,n){var e=r._rgb,a=t._rgb;return new y(e[0]+n*(a[0]-e[0]),e[1]+n*(a[1]-e[1]),e[2]+n*(a[2]-e[2]),"rgb")};var et=Math.sqrt,at=Math.pow;tt.lrgb=function(r,t,n){var e=r._rgb,a=e[0],f=e[1],o=e[2],u=t._rgb,c=u[0],i=u[1],l=u[2];return new y(et(at(a,2)*(1-n)+at(c,2)*n),et(at(f,2)*(1-n)+at(i,2)*n),et(at(o,2)*(1-n)+at(l,2)*n),"rgb")};function ft(r,t,n,e){var a,f,o,u,c,i,l,s,h,d,b,g,v;return"hsl"===e?(o=r.hsl(),u=t.hsl()):"hsv"===e?(o=r.hsv(),u=t.hsv()):"hcg"===e?(o=r.hcg(),u=t.hcg()):"hsi"===e?(o=r.hsi(),u=t.hsi()):"lch"===e||"hcl"===e?(e="hcl",o=r.hcl(),u=t.hcl()):"oklch"===e&&(o=r.oklch().reverse(),u=t.oklch().reverse()),"h"!==e.substr(0,1)&&"oklch"!==e||(c=(a=o)[0],l=a[1],h=a[2],i=(f=u)[0],s=f[1],d=f[2]),isNaN(c)||isNaN(i)?isNaN(c)?isNaN(i)?g=Number.NaN:(g=i,1!=h&&0!=h||"hsv"==e||(b=s)):(g=c,1!=d&&0!=d||"hsv"==e||(b=l)):g=c+n*(i>c&&i-c>180?i-(c+360):i<c&&c-i>180?i+360-c:i-c),void 0===b&&(b=l+n*(s-l)),v=h+n*(d-h),new y("oklch"===e?[v,b,g]:[g,b,v],e)}tt.lab=function(r,t,n){var e=r.lab(),a=t.lab();return new y(e[0]+n*(a[0]-e[0]),e[1]+n*(a[1]-e[1]),e[2]+n*(a[2]-e[2]),"lab")};var ot=function(r,t,n){return ft(r,t,n,"lch")};tt.lch=ot,tt.hcl=ot;tt.num=function(r,t,n){var e=r.num(),a=t.num();return new y(e+n*(a-e),"num")};tt.hcg=function(r,t,n){return ft(r,t,n,"hcg")};tt.hsi=function(r,t,n){return ft(r,t,n,"hsi")};tt.hsl=function(r,t,n){return ft(r,t,n,"hsl")};tt.hsv=function(r,t,n){return ft(r,t,n,"hsv")};tt.oklab=function(r,t,n){var e=r.oklab(),a=t.oklab();return new y(e[0]+n*(a[0]-e[0]),e[1]+n*(a[1]-e[1]),e[2]+n*(a[2]-e[2]),"oklab")};tt.oklch=function(r,t,n){return ft(r,t,n,"oklch")};var ut=Math.pow,ct=Math.sqrt,it=Math.PI,lt=Math.cos,st=Math.sin,ht=Math.atan2;var dt=function(r,n){for(var e=r.length,a=[0,0,0,0],f=0;f<r.length;f++){var o=r[f],u=n[f]/e,c=o._rgb;a[0]+=ut(c[0],2)*u,a[1]+=ut(c[1],2)*u,a[2]+=ut(c[2],2)*u,a[3]+=c[3]*u}return a[0]=ct(a[0]),a[1]=ct(a[1]),a[2]=ct(a[2]),a[3]>.9999999&&(a[3]=1),new y(t(a))},bt=Math.pow;function gt(t){var n="rgb",e=w("#ccc"),a=0,f=[0,1],u=[],c=[0,0],i=!1,l=[],s=!1,h=0,d=1,b=!1,g={},v=!0,p=1,m=function(r){if((r=r||["#fff","#000"])&&"string"===o(r)&&w.brewer&&w.brewer[r.toLowerCase()]&&(r=w.brewer[r.toLowerCase()]),"array"===o(r)){1===r.length&&(r=[r[0],r[0]]),r=r.slice(0);for(var t=0;t<r.length;t++)r[t]=w(r[t]);u.length=0;for(var n=0;n<r.length;n++)u.push(n/(r.length-1))}return N(),l=r},y=function(r){return r},k=function(r){return r},M=function(t,a){var f,s;if(null==a&&(a=!1),isNaN(t)||null===t)return e;if(a)s=t;else if(i&&i.length>2){var b=function(r){if(null!=i){for(var t=i.length-1,n=0;n<t&&r>=i[n];)n++;return n-1}return 0}(t);s=b/(i.length-2)}else s=d!==h?(t-h)/(d-h):1;s=k(s),a||(s=y(s)),1!==p&&(s=bt(s,p)),s=r(s=c[0]+s*(1-c[0]-c[1]),0,1);var m=Math.floor(1e4*s);if(v&&g[m])f=g[m];else{if("array"===o(l))for(var M=0;M<u.length;M++){var N=u[M];if(s<=N){f=l[M];break}if(s>=N&&M===u.length-1){f=l[M];break}if(s>N&&s<u[M+1]){s=(s-N)/(u[M+1]-N),f=w.interpolate(l[M],l[M+1],s,n);break}}else"function"===o(l)&&(f=l(s));v&&(g[m]=f)}return f},N=function(){return g={}};m(t);var _=function(r){var t=w(M(r));return s&&t[s]?t[s]():t};return _.classes=function(r){if(null!=r){if("array"===o(r))i=r,f=[r[0],r[r.length-1]];else{var t=w.analyze(f);i=0===r?[t.min,t.max]:w.limits(t,"e",r)}return _}return i},_.domain=function(r){if(!arguments.length)return f;h=r[0],d=r[r.length-1],u=[];var t=l.length;if(r.length===t&&h!==d)for(var n=0,e=Array.from(r);n<e.length;n+=1){var a=e[n];u.push((a-h)/(d-h))}else{for(var o=0;o<t;o++)u.push(o/(t-1));if(r.length>2){var c=r.map((function(t,n){return n/(r.length-1)})),i=r.map((function(r){return(r-h)/(d-h)}));i.every((function(r,t){return c[t]===r}))||(k=function(r){if(r<=0||r>=1)return r;for(var t=0;r>=i[t+1];)t++;var n=(r-i[t])/(i[t+1]-i[t]);return c[t]+n*(c[t+1]-c[t])})}}return f=[h,d],_},_.mode=function(r){return arguments.length?(n=r,N(),_):n},_.range=function(r,t){return m(r),_},_.out=function(r){return s=r,_},_.spread=function(r){return arguments.length?(a=r,_):a},_.correctLightness=function(r){return null==r&&(r=!0),b=r,N(),y=b?function(r){for(var t=M(0,!0).lab()[0],n=M(1,!0).lab()[0],e=t>n,a=M(r,!0).lab()[0],f=t+(n-t)*r,o=a-f,u=0,c=1,i=20;Math.abs(o)>.01&&i-- >0;)e&&(o*=-1),o<0?(u=r,r+=.5*(c-r)):(c=r,r+=.5*(u-r)),a=M(r,!0).lab()[0],o=a-f;return r}:function(r){return r},_},_.padding=function(r){return null!=r?("number"===o(r)&&(r=[r,r]),c=r,_):c},_.colors=function(r,n){arguments.length<2&&(n="hex");var e=[];if(0===arguments.length)e=l.slice(0);else if(1===r)e=[_(.5)];else if(r>1){var a=f[0],o=f[1]-a;e=function(r,t){for(var n=[],e=r<t,a=t,f=r;e?f<a:f>a;e?f++:f--)n.push(f);return n}(0,r).map((function(t){return _(a+t/(r-1)*o)}))}else{t=[];var u=[];if(i&&i.length>2)for(var c=1,s=i.length,h=1<=s;h?c<s:c>s;h?c++:c--)u.push(.5*(i[c-1]+i[c]));else u=f;e=u.map((function(r){return _(r)}))}return w[n]&&(e=e.map((function(r){return r[n]()}))),e},_.cache=function(r){return null!=r?(v=r,_):v},_.gamma=function(r){return null!=r?(p=r,_):p},_.nodata=function(r){return null!=r?(e=w(r),_):e},_}var vt=function(r,t,n){if(!vt[n])throw new Error("unknown blend mode "+n);return vt[n](r,t)},pt=function(r){return function(t,n){var e=w(n).rgb(),a=w(t).rgb();return w.rgb(r(e,a))}},mt=function(r){return function(t,n){var e=[];return e[0]=r(t[0],n[0]),e[1]=r(t[1],n[1]),e[2]=r(t[2],n[2]),e}};vt.normal=pt(mt((function(r){return r}))),vt.multiply=pt(mt((function(r,t){return r*t/255}))),vt.screen=pt(mt((function(r,t){return 255*(1-(1-r/255)*(1-t/255))}))),vt.overlay=pt(mt((function(r,t){return t<128?2*r*t/255:255*(1-2*(1-r/255)*(1-t/255))}))),vt.darken=pt(mt((function(r,t){return r>t?t:r}))),vt.lighten=pt(mt((function(r,t){return r>t?r:t}))),vt.dodge=pt(mt((function(r,t){return 255===r||(r=t/255*255/(1-r/255))>255?255:r}))),vt.burn=pt(mt((function(r,t){return 255*(1-(1-t/255)/(r/255))})));var yt=Math.pow,wt=Math.sin,kt=Math.cos;var Mt=Math.floor,Nt=Math.random;var _t=Math.log,xt=Math.pow,At=Math.floor,jt=Math.abs;function Et(r,t){void 0===t&&(t=null);var n={min:Number.MAX_VALUE,max:-1*Number.MAX_VALUE,sum:0,values:[],count:0};return"object"===o(r)&&(r=Object.values(r)),r.forEach((function(r){t&&"object"===o(r)&&(r=r[t]),null==r||isNaN(r)||(n.values.push(r),n.sum+=r,r<n.min&&(n.min=r),r>n.max&&(n.max=r),n.count+=1)})),n.domain=[n.min,n.max],n.limits=function(r,t){return Ot(n,r,t)},n}function Ot(r,t,n){void 0===t&&(t="equal"),void 0===n&&(n=7),"array"==o(r)&&(r=Et(r));var e=r.min,a=r.max,f=r.values.sort((function(r,t){return r-t}));if(1===n)return[e,a];var u=[];if("c"===t.substr(0,1)&&(u.push(e),u.push(a)),"e"===t.substr(0,1)){u.push(e);for(var c=1;c<n;c++)u.push(e+c/n*(a-e));u.push(a)}else if("l"===t.substr(0,1)){if(e<=0)throw new Error("Logarithmic scales are only possible for values > 0");var i=Math.LOG10E*_t(e),l=Math.LOG10E*_t(a);u.push(e);for(var s=1;s<n;s++)u.push(xt(10,i+s/n*(l-i)));u.push(a)}else if("q"===t.substr(0,1)){u.push(e);for(var h=1;h<n;h++){var d=(f.length-1)*h/n,b=At(d);if(b===d)u.push(f[b]);else{var g=d-b;u.push(f[b]*(1-g)+f[b+1]*g)}}u.push(a)}else if("k"===t.substr(0,1)){var v,p=f.length,m=new Array(p),y=new Array(n),w=!0,k=0,M=null;(M=[]).push(e);for(var N=1;N<n;N++)M.push(e+N/n*(a-e));for(M.push(a);w;){for(var _=0;_<n;_++)y[_]=0;for(var x=0;x<p;x++)for(var A=f[x],j=Number.MAX_VALUE,E=void 0,O=0;O<n;O++){var F=jt(M[O]-A);F<j&&(j=F,E=O),y[E]++,m[x]=E}for(var L=new Array(n),P=0;P<n;P++)L[P]=null;for(var B=0;B<p;B++)null===L[v=m[B]]?L[v]=f[B]:L[v]+=f[B];for(var G=0;G<n;G++)L[G]*=1/y[G];w=!1;for(var R=0;R<n;R++)if(L[R]!==M[R]){w=!0;break}M=L,++k>200&&(w=!1)}for(var Y={},$=0;$<n;$++)Y[$]=[];for(var q=0;q<p;q++)Y[v=m[q]].push(f[q]);for(var X=[],C=0;C<n;C++)X.push(Y[C][0]),X.push(Y[C][Y[C].length-1]);X=X.sort((function(r,t){return r-t})),u.push(X[0]);for(var Z=1;Z<X.length;Z+=2){var S=X[Z];isNaN(S)||-1!==u.indexOf(S)||u.push(S)}}return u}var Ft=Math.sqrt,Lt=Math.pow,Pt=Math.min,Bt=Math.max,Gt=Math.atan2,Rt=Math.abs,Yt=Math.cos,$t=Math.sin,qt=Math.exp,Xt=Math.PI;for(var Ct={cool:function(){return gt([w.hsl(180,1,.9),w.hsl(250,.7,.4)])},hot:function(){return gt(["#000","#f00","#ff0","#fff"]).mode("rgb")}},Zt={OrRd:["#fff7ec","#fee8c8","#fdd49e","#fdbb84","#fc8d59","#ef6548","#d7301f","#b30000","#7f0000"],PuBu:["#fff7fb","#ece7f2","#d0d1e6","#a6bddb","#74a9cf","#3690c0","#0570b0","#045a8d","#023858"],BuPu:["#f7fcfd","#e0ecf4","#bfd3e6","#9ebcda","#8c96c6","#8c6bb1","#88419d","#810f7c","#4d004b"],Oranges:["#fff5eb","#fee6ce","#fdd0a2","#fdae6b","#fd8d3c","#f16913","#d94801","#a63603","#7f2704"],BuGn:["#f7fcfd","#e5f5f9","#ccece6","#99d8c9","#66c2a4","#41ae76","#238b45","#006d2c","#00441b"],YlOrBr:["#ffffe5","#fff7bc","#fee391","#fec44f","#fe9929","#ec7014","#cc4c02","#993404","#662506"],YlGn:["#ffffe5","#f7fcb9","#d9f0a3","#addd8e","#78c679","#41ab5d","#238443","#006837","#004529"],Reds:["#fff5f0","#fee0d2","#fcbba1","#fc9272","#fb6a4a","#ef3b2c","#cb181d","#a50f15","#67000d"],RdPu:["#fff7f3","#fde0dd","#fcc5c0","#fa9fb5","#f768a1","#dd3497","#ae017e","#7a0177","#49006a"],Greens:["#f7fcf5","#e5f5e0","#c7e9c0","#a1d99b","#74c476","#41ab5d","#238b45","#006d2c","#00441b"],YlGnBu:["#ffffd9","#edf8b1","#c7e9b4","#7fcdbb","#41b6c4","#1d91c0","#225ea8","#253494","#081d58"],Purples:["#fcfbfd","#efedf5","#dadaeb","#bcbddc","#9e9ac8","#807dba","#6a51a3","#54278f","#3f007d"],GnBu:["#f7fcf0","#e0f3db","#ccebc5","#a8ddb5","#7bccc4","#4eb3d3","#2b8cbe","#0868ac","#084081"],Greys:["#ffffff","#f0f0f0","#d9d9d9","#bdbdbd","#969696","#737373","#525252","#252525","#000000"],YlOrRd:["#ffffcc","#ffeda0","#fed976","#feb24c","#fd8d3c","#fc4e2a","#e31a1c","#bd0026","#800026"],PuRd:["#f7f4f9","#e7e1ef","#d4b9da","#c994c7","#df65b0","#e7298a","#ce1256","#980043","#67001f"],Blues:["#f7fbff","#deebf7","#c6dbef","#9ecae1","#6baed6","#4292c6","#2171b5","#08519c","#08306b"],PuBuGn:["#fff7fb","#ece2f0","#d0d1e6","#a6bddb","#67a9cf","#3690c0","#02818a","#016c59","#014636"],Viridis:["#440154","#482777","#3f4a8a","#31678e","#26838f","#1f9d8a","#6cce5a","#b6de2b","#fee825"],Spectral:["#9e0142","#d53e4f","#f46d43","#fdae61","#fee08b","#ffffbf","#e6f598","#abdda4","#66c2a5","#3288bd","#5e4fa2"],RdYlGn:["#a50026","#d73027","#f46d43","#fdae61","#fee08b","#ffffbf","#d9ef8b","#a6d96a","#66bd63","#1a9850","#006837"],RdBu:["#67001f","#b2182b","#d6604d","#f4a582","#fddbc7","#f7f7f7","#d1e5f0","#92c5de","#4393c3","#2166ac","#053061"],PiYG:["#8e0152","#c51b7d","#de77ae","#f1b6da","#fde0ef","#f7f7f7","#e6f5d0","#b8e186","#7fbc41","#4d9221","#276419"],PRGn:["#40004b","#762a83","#9970ab","#c2a5cf","#e7d4e8","#f7f7f7","#d9f0d3","#a6dba0","#5aae61","#1b7837","#00441b"],RdYlBu:["#a50026","#d73027","#f46d43","#fdae61","#fee090","#ffffbf","#e0f3f8","#abd9e9","#74add1","#4575b4","#313695"],BrBG:["#543005","#8c510a","#bf812d","#dfc27d","#f6e8c3","#f5f5f5","#c7eae5","#80cdc1","#35978f","#01665e","#003c30"],RdGy:["#67001f","#b2182b","#d6604d","#f4a582","#fddbc7","#ffffff","#e0e0e0","#bababa","#878787","#4d4d4d","#1a1a1a"],PuOr:["#7f3b08","#b35806","#e08214","#fdb863","#fee0b6","#f7f7f7","#d8daeb","#b2abd2","#8073ac","#542788","#2d004b"],Set2:["#66c2a5","#fc8d62","#8da0cb","#e78ac3","#a6d854","#ffd92f","#e5c494","#b3b3b3"],Accent:["#7fc97f","#beaed4","#fdc086","#ffff99","#386cb0","#f0027f","#bf5b17","#666666"],Set1:["#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00","#ffff33","#a65628","#f781bf","#999999"],Set3:["#8dd3c7","#ffffb3","#bebada","#fb8072","#80b1d3","#fdb462","#b3de69","#fccde5","#d9d9d9","#bc80bd","#ccebc5","#ffed6f"],Dark2:["#1b9e77","#d95f02","#7570b3","#e7298a","#66a61e","#e6ab02","#a6761d","#666666"],Paired:["#a6cee3","#1f78b4","#b2df8a","#33a02c","#fb9a99","#e31a1c","#fdbf6f","#ff7f00","#cab2d6","#6a3d9a","#ffff99","#b15928"],Pastel2:["#b3e2cd","#fdcdac","#cbd5e8","#f4cae4","#e6f5c9","#fff2ae","#f1e2cc","#cccccc"],Pastel1:["#fbb4ae","#b3cde3","#ccebc5","#decbe4","#fed9a6","#ffffcc","#e5d8bd","#fddaec","#f2f2f2"]},St=0,Wt=Object.keys(Zt);St<Wt.length;St+=1){var It=Wt[St];Zt[It.toLowerCase()]=Zt[It]}return Object.assign(w,{analyze:Et,average:function(r,t,n){void 0===t&&(t="lrgb"),void 0===n&&(n=null);var e=r.length;n||(n=Array.from(new Array(e)).map((function(){return 1})));var a=e/n.reduce((function(r,t){return r+t}));if(n.forEach((function(r,t){n[t]*=a})),r=r.map((function(r){return new y(r)})),"lrgb"===t)return dt(r,n);for(var f=r.shift(),o=f.get(t),u=[],c=0,i=0,l=0;l<o.length;l++)if(o[l]=(o[l]||0)*n[0],u.push(isNaN(o[l])?0:n[0]),"h"===t.charAt(l)&&!isNaN(o[l])){var s=o[l]/180*it;c+=lt(s)*n[0],i+=st(s)*n[0]}var h=f.alpha()*n[0];r.forEach((function(r,e){var a=r.get(t);h+=r.alpha()*n[e+1];for(var f=0;f<o.length;f++)if(!isNaN(a[f]))if(u[f]+=n[e+1],"h"===t.charAt(f)){var l=a[f]/180*it;c+=lt(l)*n[e+1],i+=st(l)*n[e+1]}else o[f]+=a[f]*n[e+1]}));for(var d=0;d<o.length;d++)if("h"===t.charAt(d)){for(var b=ht(i/u[d],c/u[d])/it*180;b<0;)b+=360;for(;b>=360;)b-=360;o[d]=b}else o[d]=o[d]/u[d];return h/=e,new y(o,t).alpha(h>.99999?1:h,!0)},bezier:function(r){var t=function(r){var t,n,e,a,f,o,u;if(2===(r=r.map((function(r){return new y(r)}))).length)t=r.map((function(r){return r.lab()})),f=t[0],o=t[1],a=function(r){var t=[0,1,2].map((function(t){return f[t]+r*(o[t]-f[t])}));return new y(t,"lab")};else if(3===r.length)n=r.map((function(r){return r.lab()})),f=n[0],o=n[1],u=n[2],a=function(r){var t=[0,1,2].map((function(t){return(1-r)*(1-r)*f[t]+2*(1-r)*r*o[t]+r*r*u[t]}));return new y(t,"lab")};else if(4===r.length){var c;e=r.map((function(r){return r.lab()})),f=e[0],o=e[1],u=e[2],c=e[3],a=function(r){var t=[0,1,2].map((function(t){return(1-r)*(1-r)*(1-r)*f[t]+3*(1-r)*(1-r)*r*o[t]+3*(1-r)*r*r*u[t]+r*r*r*c[t]}));return new y(t,"lab")}}else{if(!(r.length>=5))throw new RangeError("No point in running bezier with only one color.");var i,l,s;i=r.map((function(r){return r.lab()})),s=r.length-1,l=function(r){for(var t=[1,1],n=1;n<r;n++){for(var e=[1],a=1;a<=t.length;a++)e[a]=(t[a]||0)+t[a-1];t=e}return t}(s),a=function(r){var t=1-r,n=[0,1,2].map((function(n){return i.reduce((function(e,a,f){return e+l[f]*Math.pow(t,s-f)*Math.pow(r,f)*a[n]}),0)}));return new y(n,"lab")}}return a}(r);return t.scale=function(){return gt(t)},t},blend:vt,brewer:Zt,Color:y,colors:Hr,contrast:function(r,t){r=new y(r),t=new y(t);var n=r.luminance(),e=t.luminance();return n>e?(n+.05)/(e+.05):(e+.05)/(n+.05)},cubehelix:function(r,n,e,a,f){void 0===r&&(r=300),void 0===n&&(n=-1.5),void 0===e&&(e=1),void 0===a&&(a=1),void 0===f&&(f=[0,1]);var u,c=0;"array"===o(f)?u=f[1]-f[0]:(u=0,f=[f,f]);var i=function(o){var i=b*((r+120)/360+n*o),l=yt(f[0]+u*o,a),s=(0!==c?e[0]+o*c:e)*l*(1-l)/2,h=kt(i),d=wt(i);return w(t([255*(l+s*(-.14861*h+1.78277*d)),255*(l+s*(-.29227*h-.90649*d)),255*(l+s*(1.97294*h)),1]))};return i.start=function(t){return null==t?r:(r=t,i)},i.rotations=function(r){return null==r?n:(n=r,i)},i.gamma=function(r){return null==r?a:(a=r,i)},i.hue=function(r){return null==r?e:("array"===o(e=r)?0===(c=e[1]-e[0])&&(e=e[1]):c=0,i)},i.lightness=function(r){return null==r?f:("array"===o(r)?(f=r,u=r[1]-r[0]):(f=[r,r],u=0),i)},i.scale=function(){return w.scale(i)},i.hue(e),i},deltaE:function(r,t,n,e,a){void 0===n&&(n=1),void 0===e&&(e=1),void 0===a&&(a=1);var f=function(r){return 360*r/(2*Xt)},o=function(r){return 2*Xt*r/360};r=new y(r),t=new y(t);var u=Array.from(r.lab()),c=u[0],i=u[1],l=u[2],s=Array.from(t.lab()),h=s[0],d=s[1],b=s[2],g=(c+h)/2,v=(Ft(Lt(i,2)+Lt(l,2))+Ft(Lt(d,2)+Lt(b,2)))/2,p=.5*(1-Ft(Lt(v,7)/(Lt(v,7)+Lt(25,7)))),m=i*(1+p),w=d*(1+p),k=Ft(Lt(m,2)+Lt(l,2)),M=Ft(Lt(w,2)+Lt(b,2)),N=(k+M)/2,_=f(Gt(l,m)),x=f(Gt(b,w)),A=_>=0?_:_+360,j=x>=0?x:x+360,E=Rt(A-j)>180?(A+j+360)/2:(A+j)/2,O=1-.17*Yt(o(E-30))+.24*Yt(o(2*E))+.32*Yt(o(3*E+6))-.2*Yt(o(4*E-63)),F=j-A;F=Rt(F)<=180?F:j<=A?F+360:F-360,F=2*Ft(k*M)*$t(o(F)/2);var L=h-c,P=M-k,B=1+.015*Lt(g-50,2)/Ft(20+Lt(g-50,2)),G=1+.045*N,R=1+.015*N*O,Y=30*qt(-Lt((E-275)/25,2)),$=-(2*Ft(Lt(N,7)/(Lt(N,7)+Lt(25,7))))*$t(2*o(Y)),q=Ft(Lt(L/(n*B),2)+Lt(P/(e*G),2)+Lt(F/(a*R),2)+$*(P/(e*G))*(F/(a*R)));return Bt(0,Pt(100,q))},distance:function(r,t,n){void 0===n&&(n="lab"),r=new y(r),t=new y(t);var e=r.get(n),a=t.get(n),f=0;for(var o in e){var u=(e[o]||0)-(a[o]||0);f+=u*u}return Math.sqrt(f)},input:m,interpolate:nt,limits:Ot,mix:nt,random:function(){for(var r="#",t=0;t<6;t++)r+="0123456789abcdef".charAt(Mt(16*Nt()));return new y(r,"hex")},scale:gt,scales:Ct,valid:function(){for(var r=[],t=arguments.length;t--;)r[t]=arguments[t];try{return new(Function.prototype.bind.apply(y,[null].concat(r))),!0}catch(r){return!1}},cmyk:M,css:yr,gl:wr,hcg:Mr,hex:Er,hsi:Br,hsl:Gr,hsv:qr,lab:Xr,lch:Cr,hcl:Zr,num:Sr,rgb:Ir,temp:Vr,kelvin:Vr,temperature:Vr,oklab:Dr,oklch:Tr,getLabWhitePoint:j,setLabWhitePoint:A}),w}));
